SliderParameter class

Constructors

SliderParameter(String label, {String? description, double? initial, double? min, double? max})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
initial double?
final
label String
final
max double?
final
min double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited